/****************************************************************************
** Meta object code from reading C++ file 'types.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../deepin-image-viewer/src/src/types.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'types.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5TypesE_t {};
} // unnamed namespace

template <> constexpr inline auto Types::qt_create_metaobjectdata<qt_meta_tag_ZN5TypesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Types",
        "ItemRole",
        "ImageUrlRole",
        "FrameIndexRole",
        "ImageAngleRole",
        "ImageType",
        "NullImage",
        "NormalImage",
        "DynamicImage",
        "SvgImage",
        "MultiImage",
        "DamagedImage",
        "NonexistImage",
        "StackPage",
        "OpenImagePage",
        "ImageViewPage",
        "SliderShowPage"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ItemRole'
        QtMocHelpers::EnumData<enum ItemRole>(1, 1, QMC::EnumFlags{}).add({
            {    2, ItemRole::ImageUrlRole },
            {    3, ItemRole::FrameIndexRole },
            {    4, ItemRole::ImageAngleRole },
        }),
        // enum 'ImageType'
        QtMocHelpers::EnumData<enum ImageType>(5, 5, QMC::EnumFlags{}).add({
            {    6, ImageType::NullImage },
            {    7, ImageType::NormalImage },
            {    8, ImageType::DynamicImage },
            {    9, ImageType::SvgImage },
            {   10, ImageType::MultiImage },
            {   11, ImageType::DamagedImage },
            {   12, ImageType::NonexistImage },
        }),
        // enum 'StackPage'
        QtMocHelpers::EnumData<enum StackPage>(13, 13, QMC::EnumFlags{}).add({
            {   14, StackPage::OpenImagePage },
            {   15, StackPage::ImageViewPage },
            {   16, StackPage::SliderShowPage },
        }),
    };
    return QtMocHelpers::metaObjectData<Types, qt_meta_tag_ZN5TypesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Types::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5TypesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5TypesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5TypesE_t>.metaTypes,
    nullptr
} };

void Types::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Types *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Types::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Types::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5TypesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Types::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
